@@ -37,8 +37,8 @@ protected:
     bool event(QEvent *e) override;
 
 private:
-    void readConfig();
-    void writeConfig();
+    KSIEVEUI_NO_EXPORT void readConfig();
+    KSIEVEUI_NO_EXPORT void writeConfig();
 
 private:
     SieveEditorGraphicalModeWidget *const mEditor;
