@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveeditorgraphicalmodewidget.h"
-#include "autocreatescripts/sievescriptparsingerrordialog.h"
 #include "ksieveui/editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
 #include "scriptsparsing/parsingutil.h"
 #include "sievescriptlistbox.h"
@@ -22,7 +21,10 @@
 #include <QVBoxLayout>
 
 using namespace KSieveUi;
-
+namespace
+{
+static const char myAutoCreateScriptDialogGroupName[] = "AutoCreateScriptDialog";
+}
 SieveEditorGraphicalModeWidget::SieveEditorGraphicalModeWidget(QWidget *parent)
     : SieveEditorGraphicalModeWidgetAbstract::SieveEditorGraphicalModeWidgetAbstract(parent)
     , mSieveScript(new SieveScriptListBox(i18n("Sieve Script"), this))
@@ -66,14 +68,14 @@ void SieveEditorGraphicalModeWidget::loadScript(const QString &doc, QString &err
 
 void SieveEditorGraphicalModeWidget::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "AutoCreateScriptDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myAutoCreateScriptDialogGroupName);
     const QList<int> size{100, 400};
     mSplitter->setSizes(group.readEntry("mainSplitter", size));
 }
 
 void SieveEditorGraphicalModeWidget::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "AutoCreateScriptDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myAutoCreateScriptDialogGroupName);
     group.writeEntry("mainSplitter", mSplitter->sizes());
 }
 
@@ -132,7 +134,12 @@ void SieveEditorGraphicalModeWidget::setImportScript(const QString &script)
             mSieveParsingWarning->animatedShow();
         }
     } else {
-        if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Error during importing script. Do you want to switch to text mode?"))) {
+        const int answer = KMessageBox::questionTwoActions(this,
+                                                           i18n("Error during importing script. Do you want to switch to text mode?"),
+                                                           QString(),
+                                                           KGuiItem(i18nc("@action:button", "Switch to Text Mode")),
+                                                           KGuiItem(i18nc("@action:button", "Do Not Switch"), QStringLiteral("dialog-cancel")));
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
             Q_EMIT switchTextMode(script);
         }
         qCDebug(LIBKSIEVE_LOG) << " cannot import script";
