@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -14,7 +14,6 @@
 #include <QTextStream>
 
 #include <cerrno>
-#include <kwidgetsaddons_version.h>
 
 using namespace KSieveUi;
 SieveEditorAbstractWidget::SieveEditorAbstractWidget(QWidget *parent)
@@ -52,20 +51,12 @@ void SieveEditorAbstractWidget::setImportScript(const QString &)
 void SieveEditorAbstractWidget::slotImport()
 {
     if (!currentscript().isEmpty()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         const int answer = KMessageBox::warningTwoActions(this,
-#else
-        const int answer = KMessageBox::warningYesNo(this,
-#endif
                                                           i18n("You will overwrite script. Do you want to continue?"),
                                                           i18n("Import Script"),
                                                           KStandardGuiItem::cont(),
                                                           KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (answer == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-        if (answer == KMessageBox::No) {
-#endif
             return;
         }
     }
