@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "multiimapvacationmanager.h"
-#include "sieveimapinstance/sieveimapinstanceinterface.h"
 #include "util/util_p.h"
 #include "vacationcheckjob.h"
 #include <kmanagesieve/sievejob.h>
@@ -14,6 +13,7 @@
 
 #include "libksieve_debug.h"
 #include "searchserverwithvacationsupportjob.h"
+#include <QVariant>
 
 using namespace KSieveUi;
 MultiImapVacationManager::MultiImapVacationManager(SieveImapPasswordProvider *passwordProvider, QObject *parent)
@@ -29,7 +29,7 @@ void MultiImapVacationManager::checkVacation(const QString &serverName, const QU
     ++mNumberOfJobs;
     if (!mKep14Support.contains(serverName)) {
         auto checkKep14Job = new CheckKolabKep14SupportJob(this);
-        checkKep14Job->setProperty("triggerScript", true);
+        checkKep14Job->setProperty("triggerScript", QVariant(true));
         checkKep14Job->setServerName(serverName);
         checkKep14Job->setServerUrl(url);
         connect(checkKep14Job, &CheckKolabKep14SupportJob::result, this, &MultiImapVacationManager::slotCheckKep14Ended);
